Enum organelle::probe::SomaData
[−]
[src]
pub enum SomaData {
Organelle {
nucleus: Box<SomaData>,
somas: Vec<SomaData>,
uuid: Uuid,
name: String,
},
Axon {
terminals: Vec<ConstraintData>,
dendrites: Vec<ConstraintData>,
uuid: Uuid,
name: String,
},
Soma {
synapse: SynapseData,
name: String,
},
}data associated with a soma, organelle, or axon
Variants
Organelledata associated with an organelle
Fields of Organelle
nucleus: Box<SomaData> | the soma at the center of an organelle |
somas: Vec<SomaData> | the rest of the somas contained in the organelle |
uuid: Uuid | unique id of the organelle |
name: String | name of the organelle |
Axondata associated with the axon of a soma
Fields of Axon
terminals: Vec<ConstraintData> | data associated with the terminals for this soma |
dendrites: Vec<ConstraintData> | data associated with the dendrites for this soma |
uuid: Uuid | unique id of the axon |
name: String | name of the axon |
Somadata associated with a custom soma
Fields of Soma
synapse: SynapseData | the type of synapse used by this soma |
name: String | the name of the soma |